"""
Author: Lukas Runt
Email: lrunt@students.zcu.cz
Date: November 04, 2023,
Version: 1.0.0
Description: Database of the expert system
"""


class Light:
    """
    Class light represents light

    Attributes
    ---------
    name: str
        a name of the light
    power: int
        power of the light in watts [W]
    luminosity: int
        luminosity of hte light in lumen [lm]
    color: int
        color of the light in Kevin [K]
    cost: int
        price of the light in czech crowns [Kč]
    light_type: string
        type of the light
    """
    def __init__(self, name, power, luminosity, color, cost, light_type):
        """
        Constructor of class lights
        """
        self.name = name
        self.power = power
        self.luminosity = luminosity
        self.color = color
        self.cost = cost
        self.light_type = light_type

    def __str__(self):
        """
        Method for generating text representation of class light
        """
        return f"Light: {self.name}, Power: {self.power}, Luminosity: {self.luminosity}, Color: {self.color}," \
               f" Cost: {self.cost}, Light type: {self.light_type} "


"""
Available lights
"""
lights = [
    Light("Stropní svítidlo Solight Plain", 15, 1200, 3000, 219, "Stropní světlo"),
    Light("Stropní svítidlo Solight CCT", 12, 900, 4000, 309, "Stropní světlo"),
    Light("LED žárovka Classic A60", 10.6, 1060, 2700, 99, "Žárovka"),
    Light("LED žárovka Classic MR16", 5.7, 465, 4000, 59, "Žárovka"),
    Light("LED žárovka Classic Mini Globe", 5, 470, 6500, 83, "Žárovka"),
    Light("LED bodové svítidlo SIMMI", 5, 420, 3000, 329, "Bodové světlo"),
    Light("Solight svítidlo pod kuchyňskou linku WO203", 9, 720, 4100, 299, "Kuchyňská linka"),
    Light("Sada 5m LED pásek RGB barevný 35W", 7, 210, 2000, 386, "Dekorativní světla"),
    Light("LED lustr LUXERA Gentis", 40, 2400, 4000, 3990, "Stropní světlo"),
    Light("Solight stolní lampička stmívatelná", 12, 700, 6000, 979, "Stolní lampa"),
    Light("Yeelight Staria Bedside Lamp Pro", 18, 4000, 2700, 1179, "Stolní lampa")
]

"""
Types of lights
"""
types_of_light = ["Žárovka", "Stropní světlo", "Bodové světlo", "Stolní lampa", "Dekorativní světla", "Kuchyňská linka"]


class Room:
    """
    Class room represents room

    Attributes
    ---------
    room_type: str
        type of the room
    area: int
        area of the room in square meters [m^2]
    speciality: dictionary
        map where key is type of speciality and value is number of these lights
    """

    def __init__(self, room_type, area, speciality):
        """
        Constructor of class room
        """
        self.room_type = room_type
        self.area = area
        self.speciality = speciality

    def __str__(self):
        """
        Text representation of class
        """
        return f"Room type: {self.room_type}, Area: {self.area}, Specialities: {self.speciality}"


"""
All types of room
"""
room_types = ["Kuchyně", "Obývací pokoj", "Ložnice", "Dětský pokoj", "Koupelna", "Záchod", "Chodba", "Sklep", "Garáž",
              "Dílna", "Pracovna", "Schodiště"]
