"""
Author: Lukas Runt
Email: lrunt@students.zcu.cz
Date: November 04, 2023
Version: 1.0.0
Description: Communication module, this module contains all strings what can be print to the user
"""

author = "Lukáš Runt"

version = "1.0.0"

separator = "------------------------------------------------------"

welcome_text = f"Vítejte ve znalostním systému pro náhrh osvětlení.\nAutor: {author}\nVerze: {version}\n{separator}"

number_of_rooms = "Zadej počet místností: "

list_of_rooms = "Seznam typů místností:"

coose_type_of_room = "Vyber místnost (Číslo typu + enter): "

enter_room_area = "Zadej velikost místnosti v m^2: "

invalid_input = "Nevalidní hodnota!"

special_option = {
    "LAMP": "Kolik pracovních stolů bude v místnosti: ",
    "DECORATION": f"Chcete mít v  místnosti dekorativní světla:\n0:Ne\n1:Ano\nVolba: "
}


def print_room_result(room):
    """
    Method generate text for introduction of representing result of the room
    :param room: room what result will be printed
    :return: generated text
    """
    return f"Pro pokoj {room.room_type} byla vybrána následující světla:\n"


def print_basic_lights(lights, required_lumen, recommended_color, room):
    """
    Method generate text for printing basic lights
    :param lights: lights what will be printed
    :param required_lumen: lumen what are required for the room
    :param recommended_color: color which is recommended fot that type of room
    :param room: the room to which are the lights generated
    :return: generated text
    """
    result = ""
    for key, value in lights.items():
        result += f"{value}x světlo: {key}\n"
    result += f"Tato světla byla vybrána, protože bylo potřeba dosáhnout {required_lumen} lm.\n" \
              f"Dále se světla vybírala podle barvy, pro pokoj {room.room_type} jsou doporučeny {translation_of_colors[recommended_color]} barvy.\n"
    return result


def print_special_lights(lights, speciality):
    """
    Method generate text for printing special lights and reasons why we chose that
    :param lights: lights what was chosen
    :param speciality: speciality of the light
    :return: generated text
    """
    result = ""
    for key, value in lights.items():
        result += f"{value}x světlo: {key}\n"
    if speciality == "LINKA":
        result += "Toto světlo bylo zvoleno pro osvětlení kuchyňské linky.\n"
    if speciality == "DECORATION":
        result += "Toto světlo bylo zvoleno z důvodu dekorace pokoje.\n"
    if speciality == "LAMPA":
        result += "Volba tohoto osvětlení je pro práci u psacího stolu.\n"
    return result

"""
Translation of enumeration from english to czech
"""
translation_of_colors = {
    "WARM": "teplé",
    "NEUTRAL": "neutrální",
    "COLD": "studené"
}
