# ------------------------------------------------------------------------------------------------
# Autor: Dominik Vladar
# E-mail: vladar21@students.zcu.cz
# Datum: 28. 10. 2023
# Verze: 1.0
# Prace z predmetu KIV/UZI
# Zapadoceska univerzita v Plzni, Fakulta aplikovanych ved
# ------------------------------------------------------------------------------------------------
# Tento modul slouzi k ukladani znalosti o datech,
# ktere jsou jiz definovana prevazne v bazi dat.
# Takovou znalosti je napriklad, ze v obyvacim pokoji obecne
# chceme teplejsi tony osvetleni (z duvodu vyssiho komfortu a uvolneni).
# ------------------------------------------------------------------------------------------------
import komunikacni_modul

# MIN a MAX nam rika, jestli mame urcitou vlastnost chtit maximalizovat/minimalizovat
# pokud neumime rozhodnout, zadame NEZAVISI
MAX = 1
MIN = 0
NEZAVISI = -1
# krome toho je mozne zadat konkretni hodnotu, ke ktere se chceme priblizit


# Trida slouzi jako obecny predek trid ZavislostSvetlaNaMistnosti a ZavislostSvetlaNaPreferencich.
# Obsahuje informaci o tom, jake vlastnosti svitidla chceme v urcite zavislosti maximalizovat/minimalizovat.
class ZavislostSvetla:
    def __init__(self,  svetelny_tok, teplota_osvetleni, cena, naklady,
                 zivotnost, zajimavost_vzhledu, moznost_menit_barvu):
        self.zavislost = [svetelny_tok, teplota_osvetleni, cena, naklady,
                          zivotnost, zajimavost_vzhledu, moznost_menit_barvu]


# Popisuje, jakym zpusobem urcita mistnost ovlivni volbu svetla.
class ZavislostSvetlaNaMistnosti(ZavislostSvetla):
    def __init__(self, mistnost,  svetelny_tok, teplota_osvetleni,
                 zajimavost_vzhledu, moznost_menit_barvu):
        ZavislostSvetla.__init__(self, svetelny_tok, teplota_osvetleni, NEZAVISI, NEZAVISI,
                                 NEZAVISI, zajimavost_vzhledu, moznost_menit_barvu)
        self.mistnost = mistnost


# Urcuje, jak uzivatelske preference ovlivni volbu svetla.
class ZavislostSvetlaNaPreferencich(ZavislostSvetla):
    def __init__(self, preference_pro_mistnost, cena, naklady,
                 zivotnost, zajimavost_vzhledu, moznost_menit_barvu):
        ZavislostSvetla.__init__(self, NEZAVISI, NEZAVISI, cena, naklady,
                                 zivotnost, zajimavost_vzhledu, moznost_menit_barvu)
        self.preference_pro_mistnost = preference_pro_mistnost


INDEX_OBYVACI_POKOJ = 0
INDEX_LOZNICE = 1
INDEX_POKOJ = 2
INDEX_KUCHYNE = 3
INDEX_CHODBA = 4
INDEX_TOALETA = 5
INDEX_KOUPELNA = 6
INDEX_GARAZ = 7
INDEX_KOTELNA = 8

mistnosti = komunikacni_modul.ziskej_mistnosti()

zavislosti_svetla_na_mistnostech = [
    ZavislostSvetlaNaMistnosti(mistnosti[INDEX_OBYVACI_POKOJ], 300, MAX, MAX, MIN),
    ZavislostSvetlaNaMistnosti(mistnosti[INDEX_LOZNICE], 300, MAX, MAX, MAX),
    ZavislostSvetlaNaMistnosti(mistnosti[INDEX_POKOJ], 300, MAX, NEZAVISI, MAX),
    ZavislostSvetlaNaMistnosti(mistnosti[INDEX_KUCHYNE], 500, MIN, MIN, MIN),
    ZavislostSvetlaNaMistnosti(mistnosti[INDEX_CHODBA], 100, NEZAVISI, MIN, MIN),
    ZavislostSvetlaNaMistnosti(mistnosti[INDEX_TOALETA], 200, NEZAVISI, MIN, MIN),
    ZavislostSvetlaNaMistnosti(mistnosti[INDEX_KOUPELNA], 200, MIN, MIN, MIN),
    ZavislostSvetlaNaMistnosti(mistnosti[INDEX_GARAZ], 150, MIN, MIN, MIN),
    ZavislostSvetlaNaMistnosti(mistnosti[INDEX_KOTELNA], 200, NEZAVISI, MIN, MIN)
]

# tento seznam se postupne naplni a bude obsahovat vsechny uzivatelske preference
preference = []


# Funkce prida novou uzivatelskou preferenci pro stanovenou mistnost.
# Preference muze obsahovat i vice podpreferenci, muze napriklad
# minimalizovat cenu a zaroven maximalizovat zajimavost vzhledu.
def pridej_preferenci(mistnost, cena, naklady, zivotnost, zajimavost_vzhledu, moznost_menit_barvu):
    preference.append(ZavislostSvetlaNaPreferencich(mistnost, cena, naklady,
                                                    zivotnost, zajimavost_vzhledu, moznost_menit_barvu))


# Funkce vraci vsechny uzivatelem definovane preference.
def ziskej_preference():
    return preference


# Vraci vsechny obecne znalosti rikajici,
# jak urcita mistnost ovlivni vyber svetla.
def ziskej_zavislosti_na_mistnostech():
    return zavislosti_svetla_na_mistnostech

