"""
Description: Tento modul řídí běh znalostního systému.
Author: Václav Ovsík, ovsikv@students.zcu.cz
Version: 1.0
Date: 6.11.2023
"""
import komunikacni_modul
from baze_znalosti import lamp_attributes
from baze_dat import light_sources, lamps, rooms, attributes


def start():
    # tato metoda obsahuje cely chod znalostniho systemu
    komunikacni_modul.start_questions()
    preferences = {}
    for room in rooms:
        room_count = komunikacni_modul.room_count(room)
        for i in range(0, room_count):
            attribute = komunikacni_modul.attribute_selection(i, room, attributes)

            if room in preferences:
                preferences[room + "(" + str(i + 1) + ")"] = lamp_attributes.get(attribute)
            else:
                preferences[room] = lamp_attributes.get(attribute)
    komunikacni_modul.print_answer(preferences, calculate_price(preferences), lamp_count(preferences))


def calculate_price(preferences):
    """
    Vypocte celkovou cenu svitidel.
    :param preferences: soubor preferenci ohledne svitidel v pokojich
    :return: celkova cena svitidel
    """
    total_price = 0
    for room, lamp in preferences.items():
        total_price += light_sources.get(lamp)
    return total_price


def lamp_count(preferences):
    """
    Zjisti kolikrat je vyuzit kazdy typ svitidla.
    :param preferences: soubor preferenci ohledne svitidel v pokojich
    :return: slovnik udavajici pocet vyuziti kazdeho typu svitidla
    """
    lamp_c = {}
    for lamp in lamps:
        lamp_c[lamp] = sum(value == lamp for room, value in preferences.items())
    return lamp_c
