# ------------------------------------------------------------------------------------------------
# Autor: Dominik Vladar
# E-mail: vladar21@students.zcu.cz
# Datum: 28. 10. 2023
# Verze: 1.0
# Prace z predmetu KIV/UZI
# Zapadoceska univerzita v Plzni, Fakulta aplikovanych ved
# ------------------------------------------------------------------------------------------------
# Tento modul slouzi k vypoctu nejvhodnejsiho osvetleni pro urcitou mistnost
# za predpokladu, ze zname uzivatelske preference. Vypocet funguje tak, ze
# kazdou vlastnost svitidla (jako napr. svetelny tok, teplota osvetleni,...)
# normalizujeme na interval <0, 1> vzhledem k ostatnim svitidlum. Svitidlo s nejvetsim
# svetelnym tokem tedy tuto vlastnost bude mit rovno 1, s nejmensim 0.
# Potom podle obecnych znalosti nebo uzivatelskych preferenci muzeme chtit tuto vlastnost
# minimalizovat nebo maximalizovat. Take se muzeme chtit pouze priblizit k optimalni hodnote,
# napriklad v pripade svetelneho toku. Pokud vsak chceme hodnotu maximalizovat nebo minimalizovat,
# namapujeme ji na interval <0, 1> a urcime, jak moc je optimalni vzhledem k nejlepsim moznym datum.
# Kazde svitidlo bude mit timto zpusobem ohodnoceny jednotlive atributy, a jako nejlepsi svitidlo
# je vybrano to, ktere ma nejvyssi soucet ohodnoceni jednotlivych vlastnosti.
# ------------------------------------------------------------------------------------------------
import komunikacni_modul

MAX = 1
MIN = 0
NEZAVISI = -1

# Jedna se o prah, nad ktery pokud se dostane urcita vlastnost, kterou hodnotime, bude vnimana jako duvod vyberu.
# Scita se dohromady cast uzivatelskych preferenci a obecnych znalosti, takze urcita vlastnost muze
# byt ohodnocena cislem z intervalu <0, 2>.
PRAH_DUVODU_VYBERU = 0.8


# Tato funkce z dostupnych preferenci a znalosti vypocte nejvhodnejsi osvetleni pro jednotlive mistnosti.
# Vraci seznam, ve formatu [nazev-mistnosti, nazev-osvetleni, duvody-zvoleni-daneho-osvetleni],
# kde duvody-zvoleni-daneho-osvetleni je opet seznam ve tvaru [[identifikator-duvodu, podrobnosti], [..., ...], ...].
# Podrobnosti, ktere jsou takto predany, slouzi k zjisteni, jestli jsme chteli urcitou vlastnost minimalizovat,
# maximalizovat, nebo se priblizit k nejake idealni hodnote.
def ziskej_vysledky():
    preference = komunikacni_modul.ziskej_preference()
    vysledky = []
    zavislosti_na_mistnostech = komunikacni_modul.ziskej_zavislosti_na_mistnostech()
    # vypocteme vysledek u kazde mistnosti (resp. uzivatelske preference pro mistnost)
    for konkretni_preference in preference:
        # najdeme odpovidajici znalost o mistnosti, a tu take zahrneme do vypoctu
        for zavislost in zavislosti_na_mistnostech:
            if zavislost.mistnost == konkretni_preference.preference_pro_mistnost:
                vybrane = ziskej_vysledek_pro_mistnost(konkretni_preference, zavislost)
                vysledky.append([zavislost.mistnost.nazev, vybrane[0], vybrane[1]])
    return vysledky


# Funkce zjisti nejlepsi mozne osvetleni pro konkretni uzivatelske preference
# a konkretnich znalostech o mistnosti. Vraci seznam [nazev_vybraneho_svetla, duvody-zvoleni-daneho-osvetleni]
def ziskej_vysledek_pro_mistnost(preference, zavislost_na_mistnosti):
    svetla = komunikacni_modul.ziskej_svetla()
    # je nutne zmenit preferenci k teplote osvetleni, protoze cim vice kelvinu, tim chladnejsi svetlo
    if preference.zavislost[1] == MAX:
        preference.zavislost[1] = MIN
    elif preference.zavislost[1] == MIN:
        preference.zavislost[1] = MAX
    # ke kazdemu atributu svitidla najdeme v datech nejmensi a nejvetsi
    # hodnotu, a pote tyto vlastnosti muzeme dele normalizovat na interval <0, 1>
    max_atributy = [0, 0, 0, 0, 0, 0, 0]
    min_atributy = [100000, 100000, 100000, 100000, 100000, 100000, 100000]
    vsechny_atributy = []
    for svetlo in svetla:
        vsechny_atributy.append([svetlo.nazev, svetlo.svetelny_tok, svetlo.teplota_osvetleni, svetlo.cena,
                                 svetlo.naklady, svetlo.zivotnost, svetlo.zajimavost_vzhledu, svetlo.moznost_menit_barvu])
        max_teplota = svetlo.teplota_osvetleni
        min_teplota = svetlo.teplota_osvetleni
        # svetlo.teplota_osvetleni muze byt seznam, pokud je
        # tato vlastnost stanovena jako rozpeti [od, do]
        if type(svetlo.teplota_osvetleni) == list:
            max_teplota = svetlo.teplota_osvetleni[1]
            min_teplota = svetlo.teplota_osvetleni[0]
        max_atributy = [
            max(max_atributy[0], svetlo.svetelny_tok),
            max(max_atributy[1], max_teplota),
            max(max_atributy[2], svetlo.cena),
            max(max_atributy[3], svetlo.naklady),
            max(max_atributy[4], svetlo.zivotnost),
            max(max_atributy[5], svetlo.zajimavost_vzhledu),
            2
        ]
        min_atributy = [
            min(min_atributy[0], svetlo.svetelny_tok),
            min(min_atributy[1], min_teplota),
            min(min_atributy[2], svetlo.cena),
            min(min_atributy[3], svetlo.naklady),
            min(min_atributy[4], svetlo.zivotnost),
            min(min_atributy[5], svetlo.zajimavost_vzhledu),
            0
        ]
    atributy_preference = preference.zavislost
    atributy_zavislosti_na_mistnosti = zavislost_na_mistnosti.zavislost

    max_ohodnoceni = 0
    duvody = []
    nazev_vybraneho_svetla = ""
    # ziskame jednotlive seznamy s prvky vlastnosti odpovidajici vzdy jednomu svitidlu
    for svetelne_atributy in vsechny_atributy:
        ohodnoceni = ohodnot_svetlo(svetelne_atributy, atributy_preference, atributy_zavislosti_na_mistnosti,
                                    min_atributy, max_atributy)
        # pokud je nove ohodnoceni lepsi, vezmeme toto svitidlo
        if ohodnoceni[0] > max_ohodnoceni:
            max_ohodnoceni = ohodnoceni[0]
            duvody = ohodnoceni[1]
            nazev_vybraneho_svetla = svetelne_atributy[0]
    return [nazev_vybraneho_svetla, duvody]


# Funkce ohodnoti jedno konkretni svetlo.
# Vraci celkove hodnoceni svetla a take informaci o tom, ktere vlastnosti nejvice
# odpovidaly preferencim uzivatele nebo znalostem o osvetleni.
def ohodnot_svetlo(atributy_svetla, atributy_preference, atributy_mistnosti, min_atributy_svetel, max_atributy_svetel):
    # je nutne vytvorit cislo z preference moznost_menit_barvu (boolean)
    if atributy_svetla[7]:
        atributy_svetla[7] = 2
    else:
        atributy_svetla[7] = 0
    duvody_volby = []
    suma = 0
    # projdeme jednotlive vlastnosti svitidla a obou preferenci
    for i in range(len(atributy_preference)):
        rozdil = max_atributy_svetel[i] - min_atributy_svetel[i]
        # normalizace vsech parametru na interval <0, 1>
        prumer = atributy_svetla[i + 1]
        min_hodnota = atributy_svetla[i+1]
        max_hodnota = atributy_svetla[i+1]
        if type(atributy_svetla[i + 1]) == list:
            prumer = (prumer[0] + prumer[1])/2
            min_hodnota = atributy_svetla[i+1][0]
            max_hodnota = atributy_svetla[i+1][1]
        normalizovane = (prumer - min_atributy_svetel[i]) / rozdil
        max_vzdalenost = max(
            abs(max_atributy_svetel[i]-min_hodnota),
            abs(min_atributy_svetel[i]-max_hodnota)
        )
        pridat = 0
        pridano = False
        # jelikoz kod je stejny pro uzivatelske preference i pro
        # znalosti o problematice osvetleni
        # (oboje ma v tomto programu stejnou vahu),
        # projdeme tyto 2 moznosti pomoci for loopu
        for preference in [atributy_preference[i], atributy_mistnosti[i]]:
            # minmax vyjadruje, jestli jsme se snazili vlastnost minimalizovat (MIN),
            # maximalizovat (MAX), nebo jsme se snazili priblizit idealni hodnote (NEZAVISI)
            minmax = NEZAVISI
            if preference == MAX:
                pridat += normalizovane
                minmax = MAX
            elif preference == MIN:
                pridat += (1-normalizovane)
                minmax = MIN
            elif preference != NEZAVISI:
                vzdalenost = abs(preference-atributy_svetla[i+1])
                pridat += vzdalenost/max_vzdalenost
            suma += pridat
            if pridat > PRAH_DUVODU_VYBERU and not pridano:
                duvody_volby.append([i, minmax])
                pridano = True
    return [suma, duvody_volby]
