"""
Description: Tento modul komunikuje s uživatelem.
Author: Václav Ovsík, ovsikv@students.zcu.cz
Version: 1.0
Date: 6.11.2023
"""
from vysvetlovaci_modul import get_reason


def start_questions():
    # vypise uvod
    print("Vítáme Vás ve znalostním systému pro návrh osvětlení.\n"
          "Níže se Vás systém zeptá na místnosti vašeho bytu a umožní vám vybrat požadavky pro jejich osvětlení.\n"
          "Ovládání: počet místností a výběr požadované vlastnosti zadáváte číslem.\n"
          "Zadání musí být vždy potvrzeno klávesou ENTER")


def room_count(room):
    """
    Zjisti od uzivatele pocet mistnosti urciteho typu.
    :param room: typ mistnosti
    :return: pocet mistnosti
    """
    divider()
    num_of_rooms = int(input("Zadejte počet místností typu " + room + "? "))
    return num_of_rooms


def attribute_selection(index, room, attributes):
    """
    Zjisti od uzivatele preferovanou vlastnost svitidla.
    :param index: index mistnosti konkretniho typu
    :param room: typ mistnosti
    :param attributes: moznosti vlastnosti svitidel
    :return: preferovana vlastnost svitidla
    """
    divider()
    print("Vyberte preferovanou vlastnost svítidla do " + str(index + 1) + ". mistnosti typu " + room)
    print_attributes(attributes)
    while True:
        try:
            selection = int(input("Zvolte preferovanou vlastnost: "))
        except ValueError:
            print("Vstup musí být celé číslo!")
            continue
        if 5 >= selection >= 1:
            break
        print("Vstup musí být v rozsahu 1-5!")
    return attributes[selection - 1]


def print_attributes(attributes):
    """
    Vypise moznosti vlastnosti svitidel.
    :param attributes: moznosti vlastnosti svitidel
    """
    for i, attribute in enumerate(attributes):
        print(str(i + 1) + ": " + attribute)


def print_answer(preferences, total_price, lamp_c):
    """
    Vypise navrh osvetleni pro jednotlive mistnosti.
    :param preferences: soubor preferenci ohledne svitidel v pokojich
    :param total_price: celkova cena svitidel
    :param lamp_c: slovnik udavajici pocet vyuziti kazdeho typu svitidla
    :return:
    """
    divider()
    for room, lamp in preferences.items():
        print("Do místnosti " + room + " bylo zvoleno svítidlo: " + lamp + ". Důvod: " + get_reason(lamp) + ".")
    print("Celkové počty svítidel: ", end=" ")
    for lamp, count in lamp_c.items():
        print(str(count) + "krát " + lamp, end=", ")
    print("\nCelková cena svítidel: " + str(total_price) + " CZK")
    input("Ukončíte stisknutím ENTER.")


def divider():
    # vypise oddelovac
    print("___________________________________________________________________")